function [xo, yo, ss3] = skill_score_ncls(D);
%
% function [xo, yo, ss3] = skill_score_ncls(D);
%==============================================================================
% kill_score_ncls $Revision: 1.0                           Date: 2015/06/18
%
%          Copyright (C) USF, Yonggang Liu, 2015. 
%
% Calculate skill scores of trajectory simulation for one drifter after 3 days'
% simulation. The skill score is defined as the normalized cumulative Lagrangian
% separation distance [Liu and Weisberg, 2011; Liu et al. 2014].  The viable
% names (d1 d2 d3, lo1, lo2, lo3, n, s, ss3 ...) are the same as those shown
% Figure 3 of Liu and Weisberg (2011).
%
% The following MATLAB functions are needed:
%  
%  sw_dist.m
%
%
% References:
%
%  Liu, Y., and R.H. Weisberg (2011), Evaluation of trajectory modeling in 
%  different dynamic regions using normalized cumulative Lagrangian separation,
%  Journal of Geophysical Research, 116, C09013, doi:10.1029/2010JC006837. 
%
%  Liu, Y., R. H. Weisberg, S. Vignudelli, and G. T. Mitchum (2014), Evaluation
%  of altimetry-derived surface current products using Lagrangian drifter
%  trajectories in the eastern Gulf of Mexico, J. Geophys. Res. Oceans, 119,
%  2827-2842, doi:10.1002/2013JC009710.
%
% Author contact information:
%
%  Yonggang Liu
%  University of South Florida
%  College of Marine Science
%  St. Petersburg, Florida 33701,
%  U.S.A.
%
% Email: yliu@mail.usf.edu
%        yliu18@gmail.com
%
% http://ocgweb.marine.usf.edu/~liu
%
%===============================================================================
  
  ind = [1:length(D.tid)];
  ind2 = [1:length(D.ti_dpls)];

  for i = 1:length(D.ti_dpls)
     
      eval(['Di = D.p' num2str(ind2(i)) ';']);

      xo(i) = D.xd((i-1)*8+1);
      yo(i) = D.yd((i-1)*8+1);

     % Calculate the Lagragian separation distance between the end locations of
     % the observed and simulated trajectories:
        
      day = 1;
      xm1 = Di.x(day*8);
      ym1 = Di.y(day*8); 
      xo1 = D.xd((i-1+day)*8);
      yo1 = D.yd((i-1+day)*8);
      d1(i) = sw_dist([yo1,ym1], [xo1,xm1],'km');
     
      day = 2;
      xm2 = Di.x(day*8);
      ym2 = Di.y(day*8);
      xo2 = D.xd((i-1+day)*8);
      yo2 = D.yd((i-1+day)*8);
      d2(i) = sw_dist([yo2,ym2], [xo2,xm2],'km');
     
      day = 3;
      xm3 = Di.x(day*8);
      ym3 = Di.y(day*8);
      xo3 = D.xd((i-1+day)*8);
      yo3 = D.yd((i-1+day)*8);
      d3(i) = sw_dist([yo3,ym3], [xo3,xm3],'km');     

     
     % Calculate the length of observed trajectory:
     
      dl = sw_dist(D.yd((i-1)*8+1:end), D.xd((i-1)*8+1:end),'km');  
         
      cdl = cumsum(dl);  % cumulative along the path
	
      lo1(i) = cdl(8);
      lo2(i) = cdl(2*8);
      lo3(i) = cdl(3*8);
	   
  end

  
 % Take an average for the first 3 days:
  % This is especially useful if the flow field has dramatic changes during
  % the 3 days, for example, in the case eddies. If a drifter is deployed in 
  % an eddy, d3 could be a lot smaller than d2, and the model skill could be
  % overestimated. By averaging, this overestimation or underestimation may be
  % limited. 
     
  cd3 = d1 + d2 + d3;
  cl3 = lo1 + lo2 + lo3;
     
  s = cd3./cl3;
     
  n = 1.0;  % Tolerance threshold n is set to be 1 following the discussions
            % of Liu and Weisberg (2011) and Liu et al. (2014).  This means 
	    % the trajectory model is considered to have no skill if the 
	    % cumulative Lagrangian sepration is larger than the length of 
	    % the drifter path.
     
  ss3  = 1 - s/n;  
 
  ss3(ss3<=0) = 0.000000001;  % Reset the negative values to 0.000000001,
                                 % so that the skill scores are in the range 
				 % of [0-1].

   %  OK!
