%==============================================================================
% kill_score_ncls_example $Revision: 1.0                    Date: 2015/06/18
%
%          Copyright (C) USF, Yonggang Liu, 2015. 
%
% This is an examle code to calculate and display the skill scores of trajectory 
% simulation in the Gulf of Mexico.  Also show the corresponding modeled and 
% observed trajectories.  This MATLAB code reproduce Figure 3 of Liu et al.(2014).
% The definition of the skill score can be found in Liu and Weisberg (2011) and
% Liu e tal. (2014).
%
% The following MATLAB functions are needed:
%  
%  skill_score_ncls.m  
%  sw_dist.m
%  plot_google_map.m
%  crop.m
%
%
% References:
%
%  Liu, Y., and R.H. Weisberg (2011), Evaluation of trajectory modeling in 
%  different dynamic regions using normalized cumulative Lagrangian separation,
%  Journal of Geophysical Research, 116, C09013, doi:10.1029/2010JC006837. 
%
%  Liu, Y., R. H. Weisberg, S. Vignudelli, and G. T. Mitchum (2014), Evaluation
%  of altimetry-derived surface current products using Lagrangian drifter
%  trajectories in the eastern Gulf of Mexico, J. Geophys. Res. Oceans, 119,
%  2827-2842, doi:10.1002/2013JC009710.
%
%
% Author contact information:
%
%  Yonggang Liu
%  University of South Florida
%  College of Marine Science
%  St. Petersburg, Florida 33701,
%  U.S.A.
%
% Email: yliu@mail.usf.edu
%        yliu18@gmail.com
%
% http://ocgweb.marine.usf.edu/~liu
%
%===============================================================================

   
 % load the trajectory model output: 
  
  load skill_score_example.mat ;  
   
   % The trajectory model output is saved in a structure D, which also comprises
   % of the observed drifter locations. The trajectory model was initialized 
   % every day from the observed drifter location, and simulated for 5 days
   % (actually 39*3 = 117 hours).  
   %
   % Observed drifter locations:
   % 
   %   D.x    hourly longitude [deg]
   %   D.y    hourly latitude [deg]
   %   D.ti   hourly timestamp [datenum]
   %
   %   D.xd   3-hourly longitude [deg]
   %   D.yd   3-hourly latitude [deg]
   %   D.tid  3-hourly timestamp [datenum]
   % 
   % Simulated drifter locations:
   %
   %   For drifter initiated on day 1:
   %   D.p1.x        3-hourly longitude [deg]
   %   D.p1.y        3-hourly latitude [deg]
   %   D.p1.dateini  time of initialization [datenum], not to be used in this code
   %   D.p1.iter     number of output time steps, not to be  used in this code
   %
   %   For drifter initiated on day 2:
   %   D.p2.x        3-hourly longitude [deg]
   %   D.p2.y        3-hourly latitude [deg]
   %   D.p2.dateini  time of initialization [datenum], not to be used in this code
   %   D.p2.iter     number of output time steps, not to be  used in this code
   %
   %   ...... and so on ...... for every day (22 days in this example).
   %
   %   D.ti_dpls     timestamp of trajectory model initialization [datenum]
    
 
  figure('visible','off'); orient tall;
  

 % Plot simulated drifter trajectories:
 % The trajectory model was initiated every day from the observed drifter
 % location. So, plot a simulated trajectory for a new virtual drifter each day.

  nday = 22;  % number of days to display  
  for i = 1:nday
      eval(['px = D.p' num2str(i) '.x(1:24);']); % 3 days
      eval(['py = D.p' num2str(i) '.y(1:24);']);
      lmod = plot(px,py,'m-'); hold on;
      plot(px(8:8:3*8),py(8:8:3*8),'mo','markersize',4); % daily markers
                                   hold on;
  end
    
 

 % plot observed drifter trajectory:
 
  nlast = (nday+2)*8+1;
  lobs = plot(D.xd(1:nlast),D.yd(1:nlast),'k-','linewidth',1); hold on;
 
  L = legend([lmod, lobs],'modeled','observed',2);
      set(L,'color','w','TextColor','k', 'fontsize',9);
  
 % label drifter timestamp every 3 days:
  ind = find(D.yd<=80);
  Dt.xd = D.xd(ind);
  Dt.yd = D.yd(ind);
  Dt.tid = D.tid(ind);
 
  ti5 = Dt.tid(1:3*8:end);
  txt5 = datestr(ti5,6);
  x5 = Dt.xd(1:3*8:end);
  y5 = Dt.yd(1:3*8:end);
 
  scatter(x5,y5,'ko','filled'); hold on
  text(x5,y5+.1,txt5,'fontsize',12,'color','w');
 
 
 % calculate skill scores:
  [xo, yo, s3o] = skill_score_ncls(D);
  
  
  cmap = colormap(jet);
  scatter(xo(~isnan(s3o)),yo(~isnan(s3o)),68,s3o(~isnan(s3o)),'filled'); caxis([0,1]); hold on;
 
  xlim = [-89.5, -83];
  ylim = [23, 29];

  xtick = [floor(xlim(1)) : ceil(xlim(end))]; 
  ytick = [floor(ylim(1)) : ceil(ylim(end))]; 
  mlr = pi*mean(ylim)/180;
   
  set(gca,'xlim',xlim,'ylim',ylim, ...
          'xtick',xtick,'ytick',ytick,...
	  'xticklabel',-xtick,'yticklabel',ytick,...
	  'tickdir','out','fontsize',10,'dataaspectratio',[1/cos(mlr) 1 1]);
  
  xlabel('Longitude (^oW)','FontSize',12);
  ylabel('Latitude (^oN)','FontSize',12);

      
  plot_google_map('maptype','satellite','alpha',1,'AutoAxis',0);

  pos = [.8, .6, .015 .2];

 % colorbarv4GE(pos,[0:.1:1],[0:.2:1],' Skill score',1)
  colorbarv4GE(pos,[0:.1:1],[0:.2:1],'s_3',1)

  png0 = ['skill_score_ncls_example.png'];
  eval(['print  -dpng -r300 ' png0 ';']); crop(png0);
 
  disp('DONE!');
